@@ -54,6 +54,12 @@ struct _WnckApplicationClass
 
   /* icon changed */
   void (* icon_changed) (WnckApplication *app);
+  
+  /* Padding for future expansion */
+  void (* pad1) (void);
+  void (* pad2) (void);
+  void (* pad3) (void);
+  void (* pad4) (void);
 };
 
 GType wnck_application_get_type (void) G_GNUC_CONST;
