@@ -57,9 +57,11 @@ struct _WnckScreenClass
   GObjectClass parent_class;
 
   /* focused window changed */
-  void (* active_window_changed)    (WnckScreen *screen);
+  void (* active_window_changed)    (WnckScreen *screen,
+                                     WnckWindow *previous_window);
   /* current workspace changed */
-  void (* active_workspace_changed) (WnckScreen *screen);
+  void (* active_workspace_changed) (WnckScreen *screen,
+                                     WnckWorkspace *previous_workspace);
   /* stacking order changed */
   void (* window_stacking_changed)  (WnckScreen *screen);
   /* window added */
@@ -96,16 +98,13 @@ struct _WnckScreenClass
   /* Viewport stuff changed */
   void (* viewports_changed)        (WnckScreen      *screen);
   
-#if 0
+  /* Padding for future expansion */
   void (* pad1) (void);
   void (* pad2) (void);
   void (* pad3) (void);
   void (* pad4) (void);
   void (* pad5) (void);
   void (* pad6) (void);
-  void (* pad7) (void);
-  void (* pad8) (void);
-#endif
 };
 
 typedef struct _WnckWorkspaceLayout WnckWorkspaceLayout;
